==> sherpa-client-0.9.4.tar.gz: sherpa-client-0.9.4/sherpa_client/api/groups/add_group.py <==
from typing import Any, Dict, Optional

import httpx

from ...client import Client
from ...models.group_name import GroupName
from ...models.new_group_desc import NewGroupDesc
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: NewGroupDesc,
) -> Dict[str, Any]:
    url = "{}/groups".format(client.base_url)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(*, response: httpx.Response) -> Optional[GroupName]:
    if response.status_code == 200:
        response_200 = GroupName.from_dict(response.json())

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[GroupName]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    json_body: NewGroupDesc,
) -> Response[GroupName]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = httpx.post(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    json_body: NewGroupDesc,
) -> Optional[GroupName]:
    """ """

    return sync_detailed(
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    json_body: NewGroupDesc,
) -> Response[GroupName]:
    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    json_body: NewGroupDesc,
) -> Optional[GroupName]:
    """ """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
        )
    ).parsed

==> sherpa-client-0.10.5.tar.gz: sherpa-client-0.10.5/sherpa_client/api/groups/add_group.py <==
from typing import Any, Dict, Optional

import httpx

from ...client import Client
from ...models.group_name import GroupName
from ...models.new_group_desc import NewGroupDesc
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    json_body: NewGroupDesc,
) -> Dict[str, Any]:
    url = "{}/groups".format(client.base_url)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "method": "post",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _parse_response(*, response: httpx.Response) -> Optional[GroupName]:
    if response.status_code == 200:
        response_200 = GroupName.from_dict(response.json())

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[GroupName]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    *,
    client: Client,
    json_body: NewGroupDesc,
) -> Response[GroupName]:
    """Add a users' group

    Args:
        json_body (NewGroupDesc):

    Returns:
        Response[GroupName]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    *,
    client: Client,
    json_body: NewGroupDesc,
) -> Optional[GroupName]:
    """Add a users' group

    Args:
        json_body (NewGroupDesc):

    Returns:
        Response[GroupName]
    """

    return sync_detailed(
        client=client,
        json_body=json_body,
    ).parsed


async def asyncio_detailed(
    *,
    client: Client,
    json_body: NewGroupDesc,
) -> Response[GroupName]:
    """Add a users' group

    Args:
        json_body (NewGroupDesc):

    Returns:
        Response[GroupName]
    """

    kwargs = _get_kwargs(
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    *,
    client: Client,
    json_body: NewGroupDesc,
) -> Optional[GroupName]:
    """Add a users' group

    Args:
        json_body (NewGroupDesc):

    Returns:
        Response[GroupName]
    """

    return (
        await asyncio_detailed(
            client=client,
            json_body=json_body,
        )
    ).parsed
